<?php

/* ---------------------------------------------------------

	RSS Combiner
	
	Description: PHP Script using MagpieRSS to merge several
	RSS feeds, sort the content based on the date and output
	it to a new RSS 2.0 or ATOM 1.0 feed.

	Version: 0.9.1

	Author: John Wrana (Jowra)
	Author URI: http://jowra.com/
	
	RSS Combiner is released under the GNU General Public License (GPL).
	http://www.gnu.org/licenses/gpl.txt

 --------------------------------------------------------- */

$rssc_version = '0.9.1';
$rssc = array('title', 'description', array(), 'excerpt', 'items');
$options_file = (dirname(__FILE__) . "/combiner.cfg");

define("MAGPIE_DIR", "./magpie/");
define("MAGPIE_CACHE_ON", true);
define("MAGPIE_CACHE_DIR", "./magpie/cache/");
define('MAGPIE_OUTPUT_ENCODING', "UTF-8");

require_once(MAGPIE_DIR."magpierss.inc");
require_once("functions.php");

if ( !file_exists($options_file)) {
	$rssc = initConfig($rssc, $options_file);
} else {
	$rssc = loadConfig($options_file);
}

// --- $_POST ---

if ( $_POST ) {
	if ( $_POST['getfeed'] ) {
		if ( $rssc[2][0] == NULL ) {
			$rssc[2][0] = str_replace('&', '&amp;', $_POST['getfeed']);
		} else {
		array_push($rssc[2], str_replace('&', '&amp;', $_POST['getfeed']));
		}
	} elseif ( $_POST['feed_title'] ) {
			$rssc['title'] = $_POST['feed_title'];
			$rssc['description'] = $_POST['feed_description'];
			if ( ($_POST['items'] < 1) || ($_POST['items'] > 20) ) {
				$rssc['items'] = 10;
			} else {
				$rssc['items'] = $_POST['items'];
			}
			if ( $_POST['excerpt'] ) {
				$rssc['excerpt'] = 1;
			} else {
			$rssc['excerpt'] = NULL;
			}
	} elseif ( $_POST['submitremove'] ) {
		array_pop($_POST);
		foreach ( $_POST as $key => $value ) {
			$check = preg_replace("/check/", "", $key);
			unset ( $rssc[2][$check] );
		}
		array_unshift ( $rssc[2], array_shift ( $rssc[2] ) );
	}
	saveConfig( $rssc, $options_file );
}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<meta http-equiv="content-type" content="text/html; charset=UTF-8" />
<title>RSS Combiner</title>
<link rel="stylesheet" type="text/css" href="styles/combiner.css" />
</head>
<body>

<div id="header">
</div>

	<div id="sidebar">
		<h1>Combined Feed</h1>
		<ul>
			<?php if ( $rssc[2][0] == NULL ) {
				echo '<li class="inactive"><p>RSS 2.0</p></li><li class="inactive"><p>ATOM 1.0</p></li>';
				} else {
				echo '<li><p><a href="rss2.php" title="Your combined RSS 2.0 Feed.">RSS 2.0</a></p></li><li><p><a href="atom.php" title="Your combined Atom 1.0 Feed.">ATOM 1.0</a></p></li>';
				}
			?>
		</ul>
		<h1>Options</h1>
		<form id="options" method="post" action="<?php echo $_SERVER['$PHP_SELF'] ?>">
		<p>
			<label for="feed_title">Feed title</label><br />
			<input type="text" value="<?php echo $rssc['title'] ?>" name="feed_title" id="feed_title" tabindex="1" /><br />
			<label for="feed_description">Description / Subtitle</label><br />
			<input type="text" value="<?php echo $rssc['description'] ?>" name="feed_description" id="feed_description" tabindex="2" /><br />
			<label for="items">Number of entries (1-20)</label><br />
			<input type="text" value="<?php echo $rssc['items'] ?>" name="items" id="items" tabindex="3" maxlength="2" /><br />
			<input type="checkbox" name="excerpt" id="excerpt" tabindex="4" <?php if ( $rssc['excerpt'] == 1 ) { echo 'checked'; } ?> /><label for="excerpt"> Output excerpts only</label><br />
			<br /><br />
			<input type="submit" id="submitoptions" tabindex="5" value="Save Options" />
		</p>
		</form>
	</div>
	<div id="feeds">
		<h1>Input Feeds</h1>

			<?php
			if ( $rssc[2][0] == NULL ) { ?>
				<p class="nofeeds">No input yet. Add some feeds.</p>
			<?php
			} else { ?>
			<form id="remove_feeds" method="post" action="<?php echo $_SERVER['$PHP_SELF'] ?>">
			<ul id="infeeds">
			<?php for ( $i=0; $i < (count($rssc[2])); $i++ ) {
				$rss = fetch_rss($rssc[2][$i]);
				$last_update = date("r", unixTime($rss->channel));
			?>
			<li>
				<h2><a href="<?php echo $rssc[2][$i]; ?>" title="<?php echo $rss->channel['title']; ?>"><?php echo $rss->channel['title']; ?></a></h2>
				<p>
					<?php echo $rss->channel['description']; ?><br />
					<input type="checkbox" name="check<?php echo $i ?>" id="check_<?php echo $i ?>" tabindex="<?php echo $i+3 ?>" /><span class="info"> | <?php echo $rss->feed_type . ' ' . $rss->feed_version; ?><br />Last Update: <?php echo $last_update; ?></span></p>
			</li>
			<?php }	?>
			</ul>
			<input id="submitremove" name="submitremove" type="submit" tabindex="<?php echo $i+3 ?>" value="Remove Selected" />
			<?php } ?>
			<?php if ( count($rssc[2]) != 0 ) { ?>
			</form>
			<?php } ?>
		<h1>Add Input Feed</h1>
		<form id="addfeed" method="post" action="<?php echo $_SERVER['$PHP_SELF'] ?>">
			<p>
			<label for="getfeed">Feed URL</label><br />
			<input type="text" value="http://" name="getfeed" id="getfeed" tabindex="<?php echo $i+4 ?>" /><br />
			<input type="submit" id="submit" tabindex="<?php echo $i+5 ?>" value="Add Feed" />
			</p>
		</form>
	</div>

<div id="footer">
<p><small><a href="http://jowra.com/journal/2006/10/rss-combiner/" title="RSS-Combiner Website">RSS-Combiner</a> <?php echo $rssc_version ?>.
&copy; 2006-2007 <a href="http://jowra.com/" title="jowra.com">John Wrana (Jowra)</a>.
Licensed under the <a href="http://www.gnu.org/licenses/gpl.txt" title="GNU General Public License">GPL</a>.</small></p>
</div>

</body>
</html>